@@ -15,7 +15,6 @@ from future.moves import subprocess
 
 logger=logging.getLogger('mldock')
 
-
 def train_model(working_dir, docker_tag, image_name, entrypoint, cmd, env=None):
     """
     Trains ML model(s) locally
@@ -23,28 +22,28 @@ def train_model(working_dir, docker_tag, image_name, entrypoint, cmd, env=None):
     :param docker_tag: [str], the Docker tag for the image
     :param image_name: [str], The name of the Docker image
     """
-    process_env = None
+    process_env = {}
     if env is not None:
-        process_env = os.environ.copy()
         process_env.update(env)
+        logger.info("Training Environment = {ENV_VARS}".format(ENV_VARS=process_env))
 
     client = docker.from_env()
 
     try:
+        base_ml_path = 'opt/ml'
         container = client.containers.run(
-            image="{image}:{tag}".format(image=image_name, tag=docker_tag),
+            image="{IMAGE}:{TAG}".format(IMAGE=image_name, TAG=docker_tag),
             entrypoint=entrypoint,
             command=cmd,
             environment=process_env,
             remove=True,
             tty=True,
             volumes={
-                '{test_path}/config'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/input/config', 'mode': 'rw'},
-                '{test_path}/data'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/input/data', 'mode': 'rw'},
-                '{test_path}/model'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/model', 'mode': 'rw'},
-                '{test_path}/output'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/output', 'mode': 'rw'}
+                Path(working_dir,'config').absolute().as_posix(): {'bind': '/opt/ml/input/config', 'mode': 'rw'},
+                Path(working_dir,'data').absolute().as_posix(): {'bind': '/opt/ml/input/data', 'mode': 'rw'},
+                Path(working_dir,'model').absolute().as_posix(): {'bind': '/opt/ml/model', 'mode': 'rw'},
+                Path(working_dir,'output').absolute().as_posix(): {'bind': '/opt/ml/output', 'mode': 'rw'}
             },
-            auto_remove=True,
             detach=True,
             stream=True
         )
@@ -67,14 +66,17 @@ def deploy_model(working_dir, docker_tag, image_name, entrypoint, cmd, port=8080
     :param image_name: [str], The name of the Docker image
     """
 
-    process_env = os.environ.copy()
-    if isinstance(env, dict) & len(env) > 0:
+    process_env = {}
+    if isinstance(env, dict) and len(env) > 0:
         process_env.update(env)
+        logger.info("Deploy Environment = {ENV_VARS}".format(ENV_VARS=process_env))
+
     client = docker.from_env()
 
     try:
+        base_ml_path = 'opt/ml'
         container = client.containers.run(
-            image="{image}:{tag}".format(image=image_name, tag=docker_tag),
+            image="{IMAGE}:{TAG}".format(IMAGE=image_name, TAG=docker_tag),
             entrypoint=entrypoint,
             command=cmd,
             environment=process_env,
@@ -82,10 +84,10 @@ def deploy_model(working_dir, docker_tag, image_name, entrypoint, cmd, port=8080
             remove=True,
             tty=True,
             volumes={
-                '{test_path}/config'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/input/config', 'mode': 'rw'},
-                '{test_path}/data'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/input/data', 'mode': 'rw'},
-                '{test_path}/model'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/model', 'mode': 'rw'},
-                '{test_path}/output'.format(test_path=os.path.abspath(working_dir)): {'bind': '/opt/ml/output', 'mode': 'rw'}
+                Path(working_dir,'config').absolute().as_posix(): {'bind': '/opt/ml/input/config', 'mode': 'rw'},
+                Path(working_dir,'data').absolute().as_posix(): {'bind': '/opt/ml/input/data', 'mode': 'rw'},
+                Path(working_dir,'model').absolute().as_posix(): {'bind': '/opt/ml/model', 'mode': 'rw'},
+                Path(working_dir,'output').absolute().as_posix(): {'bind': '/opt/ml/output', 'mode': 'rw'}
             },
             auto_remove=True,
             detach=True,
@@ -126,7 +128,7 @@ def docker_build(
     target_dir_name: str,
     requirements_file_path: str,
     no_cache: bool,
-    client = None
+    docker_tag: str
 ):
     """Runs the build executable from script path, passing a set of arguments in a command line subprocess.
 
@@ -138,23 +140,22 @@ def docker_build(
         module_path (str):
         target_dir_name (str):
         requirements_file_path (str):
+        docker_tag (str): the docker tag to build
     """
 
-    # if client is None:
-        # client = docker.from_env()
-    client = docker.APIClient(base_url=os.environ.get('DOCKER_HOST','tcp://127.0.0.1:1234'))
+    client = docker.APIClient(base_url=os.environ.get('DOCKER_HOST','tcp://127.0.0.1:2375'))
 
     try:
         short_log = []
 
         logs = client.build(
-            tag=image_name,
+            tag="{IMAGE}:{TAG}".format(IMAGE=image_name, TAG=docker_tag),
             path='.',
-            dockerfile=os.path.join(dockerfile_path, 'Dockerfile'),
+            dockerfile=Path(os.path.join(dockerfile_path, 'Dockerfile')).as_posix(),
             buildargs={
-                'module_path': module_path,
-                'target_dir_name': target_dir_name,
-                'requirements_file_path': requirements_file_path
+                'module_path': Path(module_path).as_posix(),
+                'target_dir_name': Path(target_dir_name).as_posix(),
+                'requirements_file_path': Path(requirements_file_path).as_posix()
             },
             quiet=False,
             nocache=no_cache,
