@@ -9,15 +9,11 @@ from mldock.config.config_manager import \
         HyperparameterConfigManager, InputDataConfigManager
 from mldock.api.local import \
     _copy_boilerplate_to_dst, _rename_file
+from mldock.platform_helpers.utils import _write_json
+
 
 logger=logging.getLogger('mldock')
 
-def _write_json(obj, path):  # type: (object, str) -> None
-    """Write a serializeable object as a JSON file."""
-    with open(path, "w") as f:
-        json.dump(obj, f, indent=4)
-        f.write('\n')
-
 def generic_init(dir, helper_library_path, mldock_config, testing_framework, service, container_only, template_dir):
 
     logger.info("Initializing Assets - Generic Container")
@@ -75,17 +71,8 @@ def generic_init(dir, helper_library_path, mldock_config, testing_framework, ser
         logger.info("Adding {} service".format(service))
         _copy_boilerplate_to_dst(os.path.join(template_dir,'service',service), service_directory)
 
-def _make_sagemaker_input_data_configs(data_channels: list):
-    """restructures a list of data names as sagemaker input data configs"""
-    return {name: {} for name in data_channels}
-
-def _extract_data_channels_from_mldock(mldock_data: list):
-
-    data_channels = [
-        data_config['channel'] for data_config in mldock_data
-    ]
-
-    return _make_sagemaker_input_data_configs(data_channels=data_channels)
+    logger.info("Adding some extra goodies")
+    _write_json({}, Path(dir,'config/hyperparameters.json'))
 
 def sagemaker_init(dir, helper_library_path, mldock_config, no_prompt, testing_framework, service, container_only, template_dir):
 
@@ -147,9 +134,4 @@ def sagemaker_init(dir, helper_library_path, mldock_config, no_prompt, testing_f
 
     logger.info("Adding dummy sagemaker goodies")
     _write_json({}, Path(dir,'config/hyperparameters.json'))
-
-    # get list of dataset names
-    mldock_data = mldock_config.get("data", None)
-    input_config_config = _extract_data_channels_from_mldock(mldock_data)
-    _write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
     _write_json({"current_host": "dummy_host", "hosts": ["dummy_host", "second_dummy_host"]}, Path(dir,'config/resourceconfig.json'))
