@@ -48,62 +48,76 @@ def pretty_build_logs(line: dict):
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option('--no-cache', help='builds container from scratch', is_flag=True)
+@click.option('--tag', help='docker tag', type=str, default='latest')
+@click.option('--stage', help='environment to stage.')
 @click.pass_obj
-def build(obj, dir, no_cache):
+def build(obj, dir, no_cache, tag, stage):
     """build image using docker
 
     Args:
         dir (str): directory containing model assets
     """
     helper_library_path = obj['helper_library_path']
+    mldock_manager = MLDockConfigManager(
+        filepath=os.path.join(dir, ".mldock.json")
+    )
+    # get mldock_module_dir name
+    mldock_config = mldock_manager.get_config()
+    image_name = mldock_config.get("image_name", None)
+    container_dir = mldock_config.get("container_dir", None)
+    module_path = os.path.join(
+        dir,
+        mldock_config.get("mldock_module_dir", "src"),
+    )
+    dockerfile_path = os.path.join(
+        dir,
+        mldock_config.get("mldock_module_dir", "src"),
+        container_dir
+    )
+    requirements_file_path = os.path.join(
+        dir,
+        mldock_config.get("requirements_dir", "requirements.txt")
+    )
+
     try:
-        mldock_manager = MLDockConfigManager(
-            filepath=os.path.join(dir, ".mldock.json")
+        stages = mldock_config.get("stages", None)
+
+        if stage is not None:
+            tag = stages[stage]['tag']
+
+        if tag is None:
+            raise Exception("tag is not valid. Either choose a stage or set a tag manually")
+    except KeyError as exception:
+        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
+        sys.exit(-1)
+    except Exception as exception:
+        logger.error(exception)
+        sys.exit(-1)
+
+    try:
+        logger.info("\nStarting build...\n")
+        docker_build(
+            image_name=image_name,
+            dockerfile_path=dockerfile_path,
+            module_path=module_path,
+            target_dir_name=mldock_config.get("mldock_module_dir", "src"),
+            requirements_file_path=requirements_file_path,
+            no_cache=no_cache,
+            docker_tag=tag
         )
-        # get mldock_module_dir name
-        mldock_config = mldock_manager.get_config()
-        image_name = mldock_config.get("image_name", None)
-        container_dir = mldock_config.get("container_dir", None)
-        module_path = os.path.join(
-            dir,
-            mldock_config.get("mldock_module_dir", "src"),
-        )
-        dockerfile_path = os.path.join(
-            dir,
-            mldock_config.get("mldock_module_dir", "src"),
-            container_dir
-        )
-        requirements_file_path = os.path.join(
-            dir,
-            mldock_config.get("requirements.txt", "requirements.txt")
-        )
-        if image_name is None:
-            raise Exception("\nimage_name cannot be None")
-        elif image_name.endswith(":latest"):
-            raise Exception("\nImage version is not supported at this point. Please remove :latest versioning")
-        else:
-            logger.info("\nStarting build...\n")
-            docker_build(
-                image_name=image_name,
-                dockerfile_path=dockerfile_path,
-                module_path=module_path,
-                target_dir_name=mldock_config.get("mldock_module_dir", "src"),
-                requirements_file_path=requirements_file_path,
-                no_cache=no_cache
-            )
-            logger.info("\nBuild Complete! ヽ(´▽`)/\n")
+        logger.info("\nBuild Complete! ヽ(´▽`)/\n")
     except subprocess.CalledProcessError as e:
-        logger.debug(e.output)
-        raise
+        logger.error(e.output)
+        sys.exit(-1)
     except Exception as e:
         logger.error("{}".format(e))
         sys.exit(-1)
 
 @click.command()
 @click.option('--payload', default=None, help='path to payload file', required=True)
-@click.option('--content-type', help='format of payload', type=click.Choice(['json', 'csv'], case_sensitive=False))
+@click.option('--content-type', default='json', help='format of payload', type=click.Choice(['json', 'csv'], case_sensitive=False))
 @click.option('--host', help='host url at which model is served', type=str, default='http://127.0.0.1:8080/invocations')
-def predict( payload, content_type, host):
+def predict(payload, content_type, host):
     """
     Command to run curl predict against an host served on localhost:8080
     """
@@ -115,7 +129,8 @@ def predict( payload, content_type, host):
                 pretty_output = predict_request.send_json(filepath=payload, host=host)
             elif content_type in ['text/csv', 'csv']:
                 pretty_output = predict_request.send_csv(filepath=payload, host=host)
-
+            else:
+                raise Exception("Content-type is not supported.")
             logger.info(pretty_output)
             logger.info("\nPrediction Complete! ヽ(´▽`)/")
     except Exception as e:
@@ -125,7 +140,7 @@ def predict( payload, content_type, host):
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option('--tag', help='docker tag', type=str, default='latest')
-@click.option('--stage', default='dev', help='environment to stage.', required=True)
+@click.option('--stage', help='environment to stage.')
 @click.pass_obj
 def train(obj, dir, tag, stage):
     """
@@ -145,6 +160,21 @@ def train(obj, dir, tag, stage):
     container_dir = mldock_config.get("container_dir", None)
     helper_library_path = obj['helper_library_path']
 
+    try:
+        stages = mldock_config.get("stages", None)
+
+        if stage is not None:
+            tag = stages[stage]['tag']
+
+        if tag is None:
+            raise Exception("tag is not valid. Either choose a stage or set a tag manually")
+    except KeyError as exception:
+        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
+        sys.exit(-1)
+    except Exception as exception:
+        logger.error(exception)
+        sys.exit(-1)
+
     project_env_vars = mldock_config.get('environment', {})
     env_vars = collect_mldock_environment_variables(
         stage=stage,
@@ -185,8 +215,8 @@ def train(obj, dir, tag, stage):
         logger.error("This is not a mldock directory: {}".format(dir))
         sys.exit(-1)
     except subprocess.CalledProcessError as e:
-        logger.debug(e.output)
-        raise
+        logger.error(e.output)
+        sys.exit(-1)
     except Exception as e:
         logger.error("{}".format(e))
         sys.exit(-1)
@@ -195,7 +225,7 @@ def train(obj, dir, tag, stage):
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option('--tag', help='docker tag', type=str, default='latest')
 @click.option('--port', help='host url at which model is served', type=str, default='8080')
-@click.option('--stage', default='dev', help='environment to stage.', required=True)
+@click.option('--stage', help='environment to stage.')
 @click.pass_obj
 def deploy(obj, dir, tag, port, stage):
     """
@@ -216,6 +246,21 @@ def deploy(obj, dir, tag, port, stage):
     container_dir = mldock_config.get("container_dir", None)
     helper_library_path = obj['helper_library_path']
 
+    try:
+        stages = mldock_config.get("stages", None)
+
+        if stage is not None:
+            tag = stages[stage]['tag']
+
+        if tag is None:
+            raise Exception("tag is not valid. Either choose a stage or set a tag manually")
+    except KeyError as exception:
+        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
+        sys.exit(-1)
+    except Exception as exception:
+        logger.error(exception)
+        sys.exit(-1)
+
     project_env_vars = mldock_config.get('environment', {})
     env_vars = collect_mldock_environment_variables(
         stage=stage,
@@ -259,8 +304,8 @@ def deploy(obj, dir, tag, port, stage):
         logger.error("This is not a mldock directory: {}".format(dir))
         sys.exit(-1)
     except subprocess.CalledProcessError as e:
-        logger.debug(e.output)
-        raise
+        logger.error(e.output)
+        sys.exit(-1)
     except Exception as e:
         logger.error("{}".format(e))
         sys.exit(-1)
