@@ -1,9 +1,12 @@
 import os
+import environs
 import json
 from pathlib import Path
 import logging
 import re
 
+from mldock.platform_helpers import utils
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(None)
 
@@ -32,8 +35,12 @@ class Environment:
     output_channel_regex = None
     output_channel_regex = None
     hyperparameters_file = None
+    environment_variables = environs.Env()
 
     def __init__(self, base_dir, **kwargs):
+
+        
+        self.environment_variables.read_env()
         self.base_dir = base_dir
         self.hyperparameters_file = kwargs.get(
             'hyperparameters_file', 'hyperparameters.json'
@@ -113,12 +120,6 @@ class Environment:
         with open(path, "r") as f:
             return json.load(f)
 
-    @staticmethod
-    def _write_json(obj, path):  # type: (object, str) -> None
-        """Write a serializeable object as a JSON file."""
-        with open(path, "w") as f:
-            json.dump(obj, f)
-    
     def setup_hyperparameters(self):
         """Retrieves the env vars matching hyperparameters regex and updates config"""
         hyperparameters = self._read_json(
@@ -129,14 +130,12 @@ class Environment:
             regex=self.hyperparamters_regex,
             flat=False
         )
-
-        # updated_hparams = json.loads(updated_hparams)
         
         hyperparameters.update(
             updated_hparams
         )
 
-        self._write_json(
+        utils._write_json(
             obj=hyperparameters,
             path=self.hyperparameters_filepath
         )
